summaryrefslogtreecommitdiffstats
path: root/dcop/dcopidl2cpp/skel.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /dcop/dcopidl2cpp/skel.cpp
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'dcop/dcopidl2cpp/skel.cpp')
-rw-r--r--dcop/dcopidl2cpp/skel.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/dcop/dcopidl2cpp/skel.cpp b/dcop/dcopidl2cpp/skel.cpp
index b3d14fb13..5cc30de3e 100644
--- a/dcop/dcopidl2cpp/skel.cpp
+++ b/dcop/dcopidl2cpp/skel.cpp
@@ -92,7 +92,7 @@ void generateSkel( const TQString& idl, const TQString& filename, TQDomElement d
TQDomElement n = e.firstChild().toElement();
Q_ASSERT( n.tagName() == "NAME" );
TQString className = n.firstChild().toText().data();
// tqfind dcop parent ( rightmost super class )
TQString DCOPParent;
TQDomElement s = n.nextSibling().toElement();
for( ; !s.isNull(); s = s.nextSibling().toElement() ) {
@@ -177,7 +177,7 @@ void generateSkel( const TQString& idl, const TQString& filename, TQDomElement d
TQString namespace_tmp = className;
str << endl;
for(;;) {
- int pos = namespace_tmp.tqfind( "::" );
+ int pos = namespace_tmp.find( "::" );
if( pos < 0 ) {
className = namespace_tmp;
break;
@@ -223,7 +223,7 @@ void generateSkel( const TQString& idl, const TQString& filename, TQDomElement d
str << "\t fdict->insert( " << className << "_ftable[i][1], new int( i ) );" << endl;
str << " }" << endl;
- str << " int* fp = fdict->tqfind( fun );" << endl;
+ str << " int* fp = fdict->find( fun );" << endl;
str << " switch ( fp?*fp:-1) {" << endl;
}
s = n.nextSibling().toElement();
@@ -92,7 +92,7 @@ void generateSkel( const TQString& idl, const TQString& filename, TQDomElement d
Q_ASSERT( n.tagName() == "NAME" );
TQString className = n.firstChild().toText().data();
- // tqfind dcop parent ( rightmost super class )
+ // find dcop parent ( rightmost super class )
TQString DCOPParent;
TQDomElement s = n.nextSibling().toElement();